from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MagneticField(_message.Message):
    __slots__ = ["header", "magnetic_field", "magnetic_field_covariance"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAGNETIC_FIELD_FIELD_NUMBER: _ClassVar[int]
    MAGNETIC_FIELD_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    magnetic_field: _vector3_pb2.Vector3
    magnetic_field_covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., magnetic_field: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., magnetic_field_covariance: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/graph_msgs/msg/edges.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/rolling/graph_msgs/msg/edges.proto\x12+make87_messages_ros2.rolling.graph_msgs.msg\"*\n\x05\x45\x64ges\x12\x10\n\x08node_ids\x18\x01 \x03(\r\x12\x0f\n\x07weights\x18\x02 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.graph_msgs.msg.edges_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_EDGES']._serialized_start=104
  _globals['_EDGES']._serialized_end=146
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ItineraryReached(_message.Message):
    __slots__ = ["participant", "plan", "reached_checkpoints", "progress_version"]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    REACHED_CHECKPOINTS_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_VERSION_FIELD_NUMBER: _ClassVar[int]
    participant: int
    plan: int
    reached_checkpoints: _containers.RepeatedScalarFieldContainer[int]
    progress_version: int
    def __init__(self, participant: _Optional[int] = ..., plan: _Optional[int] = ..., reached_checkpoints: _Optional[_Iterable[int]] = ..., progress_version: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JointConstraint(_message.Message):
    __slots__ = ["header", "joint_name", "position", "tolerance_above", "tolerance_below", "weight"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_NAME_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    TOLERANCE_ABOVE_FIELD_NUMBER: _ClassVar[int]
    TOLERANCE_BELOW_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    joint_name: str
    position: float
    tolerance_above: float
    tolerance_below: float
    weight: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., joint_name: _Optional[str] = ..., position: _Optional[float] = ..., tolerance_above: _Optional[float] = ..., tolerance_below: _Optional[float] = ..., weight: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/leo_msgs/srv/set_imu_calibration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/leo_msgs/srv/set_imu_calibration.proto\x12\'make87_messages_ros2.jazzy.leo_msgs.srv\"Y\n\x18SetImuCalibrationRequest\x12\x13\n\x0bgyro_bias_x\x18\x01 \x01(\x01\x12\x13\n\x0bgyro_bias_y\x18\x02 \x01(\x01\x12\x13\n\x0bgyro_bias_z\x18\x03 \x01(\x01\",\n\x19SetImuCalibrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.leo_msgs.srv.set_imu_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETIMUCALIBRATIONREQUEST']._serialized_start=110
  _globals['_SETIMUCALIBRATIONREQUEST']._serialized_end=199
  _globals['_SETIMUCALIBRATIONRESPONSE']._serialized_start=201
  _globals['_SETIMUCALIBRATIONRESPONSE']._serialized_end=245
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RobotInfo15(_message.Message):
    __slots__ = ["penalty", "secs_till_unpenalised"]
    PENALTY_FIELD_NUMBER: _ClassVar[int]
    SECS_TILL_UNPENALISED_FIELD_NUMBER: _ClassVar[int]
    penalty: int
    secs_till_unpenalised: int
    def __init__(self, penalty: _Optional[int] = ..., secs_till_unpenalised: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.object_recognition_msgs.msg import object_type_pb2 as _object_type_pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_pb2 as _mesh_pb2
from make87_messages_ros2.humble.shape_msgs.msg import plane_pb2 as _plane_pb2
from make87_messages_ros2.humble.shape_msgs.msg import solid_primitive_pb2 as _solid_primitive_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CollisionObject(_message.Message):
    __slots__ = ["header", "ros2_header", "pose", "id", "type", "primitives", "primitive_poses", "meshes", "mesh_poses", "planes", "plane_poses", "subframe_names", "subframe_poses", "operation"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVES_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVE_POSES_FIELD_NUMBER: _ClassVar[int]
    MESHES_FIELD_NUMBER: _ClassVar[int]
    MESH_POSES_FIELD_NUMBER: _ClassVar[int]
    PLANES_FIELD_NUMBER: _ClassVar[int]
    PLANE_POSES_FIELD_NUMBER: _ClassVar[int]
    SUBFRAME_NAMES_FIELD_NUMBER: _ClassVar[int]
    SUBFRAME_POSES_FIELD_NUMBER: _ClassVar[int]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    pose: _pose_pb2.Pose
    id: str
    type: _object_type_pb2.ObjectType
    primitives: _containers.RepeatedCompositeFieldContainer[_solid_primitive_pb2.SolidPrimitive]
    primitive_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    meshes: _containers.RepeatedCompositeFieldContainer[_mesh_pb2.Mesh]
    mesh_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    planes: _containers.RepeatedCompositeFieldContainer[_plane_pb2.Plane]
    plane_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    subframe_names: _containers.RepeatedScalarFieldContainer[str]
    subframe_poses: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    operation: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., id: _Optional[str] = ..., type: _Optional[_Union[_object_type_pb2.ObjectType, _Mapping]] = ..., primitives: _Optional[_Iterable[_Union[_solid_primitive_pb2.SolidPrimitive, _Mapping]]] = ..., primitive_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., meshes: _Optional[_Iterable[_Union[_mesh_pb2.Mesh, _Mapping]]] = ..., mesh_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., planes: _Optional[_Iterable[_Union[_plane_pb2.Plane, _Mapping]]] = ..., plane_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., subframe_names: _Optional[_Iterable[str]] = ..., subframe_poses: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., operation: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rclpy_message_converter_msgs.msg import nested_uint8_array_test_message_pb2 as _nested_uint8_array_test_message_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NestedUint8ArrayTestServiceRequest(_message.Message):
    __slots__ = ["header", "input"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    input: _nested_uint8_array_test_message_pb2.NestedUint8ArrayTestMessage
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., input: _Optional[_Union[_nested_uint8_array_test_message_pb2.NestedUint8ArrayTestMessage, _Mapping]] = ...) -> None: ...

class NestedUint8ArrayTestServiceResponse(_message.Message):
    __slots__ = ["header", "output"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    output: _nested_uint8_array_test_message_pb2.NestedUint8ArrayTestMessage
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., output: _Optional[_Union[_nested_uint8_array_test_message_pb2.NestedUint8ArrayTestMessage, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SwitchControllerRequest(_message.Message):
    __slots__ = ["activate_controllers", "deactivate_controllers", "strictness", "activate_asap", "timeout"]
    ACTIVATE_CONTROLLERS_FIELD_NUMBER: _ClassVar[int]
    DEACTIVATE_CONTROLLERS_FIELD_NUMBER: _ClassVar[int]
    STRICTNESS_FIELD_NUMBER: _ClassVar[int]
    ACTIVATE_ASAP_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    activate_controllers: _containers.RepeatedScalarFieldContainer[str]
    deactivate_controllers: _containers.RepeatedScalarFieldContainer[str]
    strictness: int
    activate_asap: bool
    timeout: _duration_pb2.Duration
    def __init__(self, activate_controllers: _Optional[_Iterable[str]] = ..., deactivate_controllers: _Optional[_Iterable[str]] = ..., strictness: _Optional[int] = ..., activate_asap: bool = ..., timeout: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class SwitchControllerResponse(_message.Message):
    __slots__ = ["ok"]
    OK_FIELD_NUMBER: _ClassVar[int]
    ok: bool
    def __init__(self, ok: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/rename_robot_state_in_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/jazzy/moveit_msgs/srv/rename_robot_state_in_warehouse.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\"W\n\"RenameRobotStateInWarehouseRequest\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\x12\r\n\x05robot\x18\x03 \x01(\t\"%\n#RenameRobotStateInWarehouseResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.rename_robot_state_in_warehouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RENAMEROBOTSTATEINWAREHOUSEREQUEST']._serialized_start=128
  _globals['_RENAMEROBOTSTATEINWAREHOUSEREQUEST']._serialized_end=215
  _globals['_RENAMEROBOTSTATEINWAREHOUSERESPONSE']._serialized_start=217
  _globals['_RENAMEROBOTSTATEINWAREHOUSERESPONSE']._serialized_end=254
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetIORequest(_message.Message):
    __slots__ = ["fun", "pin", "state"]
    FUN_FIELD_NUMBER: _ClassVar[int]
    PIN_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    fun: int
    pin: int
    state: float
    def __init__(self, fun: _Optional[int] = ..., pin: _Optional[int] = ..., state: _Optional[float] = ...) -> None: ...

class SetIOResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/canopen_interfaces/msg/co_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/canopen_interfaces/msg/co_data.proto\x12\x33make87_messages_ros2.rolling.canopen_interfaces.msg\"7\n\x06\x43OData\x12\r\n\x05index\x18\x01 \x01(\r\x12\x10\n\x08subindex\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.canopen_interfaces.msg.co_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CODATA']._serialized_start=122
  _globals['_CODATA']._serialized_end=177
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Robot(_message.Message):
    __slots__ = ["player_number", "team", "state", "facing"]
    PLAYER_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    FACING_FIELD_NUMBER: _ClassVar[int]
    player_number: int
    team: int
    state: int
    facing: int
    def __init__(self, player_number: _Optional[int] = ..., team: _Optional[int] = ..., state: _Optional[int] = ..., facing: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/novatel_gps_msgs/msg/novatel_rx_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as make87__messages__ros2_dot_humble_dot_novatel__gps__msgs_dot_msg_dot_novatel__message__header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/novatel_gps_msgs/msg/novatel_rx_status.proto\x12\x30make87_messages_ros2.humble.novatel_gps_msgs.msg\x1a!make87_messages/core/header.proto\x1aMmake87_messages_ros2/humble/novatel_gps_msgs/msg/novatel_message_header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd1\x02\n\x0fNovatelRxStatus\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x62\n\x12novatel_msg_header\x18\x03 \x01(\x0b\x32\x46.make87_messages_ros2.humble.novatel_gps_msgs.msg.NovatelMessageHeader\x12\r\n\x05\x65rror\x18\x04 \x01(\r\x12\x0e\n\x06rxstat\x18\x05 \x01(\r\x12\x10\n\x08\x61ux1stat\x18\x06 \x01(\r\x12\x10\n\x08\x61ux2stat\x18\x07 \x01(\r\x12\x10\n\x08\x61ux3stat\x18\x08 \x01(\r\x12\x10\n\x08\x61ux4stat\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.novatel_gps_msgs.msg.novatel_rx_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NOVATELRXSTATUS']._serialized_start=296
  _globals['_NOVATELRXSTATUS']._serialized_end=633
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/cor_status_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/cor_status_info.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\"\xda\x01\n\rCorStatusInfo\x12\x10\n\x08protocol\x18\x01 \x01(\r\x12\x12\n\nerr_status\x18\x02 \x01(\r\x12\x10\n\x08msg_used\x18\x03 \x01(\r\x12\x15\n\rcorrection_id\x18\x04 \x01(\r\x12\x16\n\x0emsg_type_valid\x18\x05 \x01(\x08\x12\x1a\n\x12msg_sub_type_valid\x18\x06 \x01(\x08\x12\x18\n\x10msg_input_handle\x18\x07 \x01(\x08\x12\x15\n\rmsg_encrypted\x18\x08 \x01(\r\x12\x15\n\rmsg_decrypted\x18\t \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.cor_status_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CORSTATUSINFO']._serialized_start=123
  _globals['_CORSTATUSINFO']._serialized_end=341
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_air_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sbg_driver.msg import sbg_air_data_status_pb2 as make87__messages__ros2_dot_jazzy_dot_sbg__driver_dot_msg_dot_sbg__air__data__status__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/sbg_driver/msg/sbg_air_data.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\x1a\x43make87_messages_ros2/jazzy/sbg_driver/msg/sbg_air_data_status.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x9e\x02\n\nSbgAirData\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12K\n\x06status\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.jazzy.sbg_driver.msg.SbgAirDataStatus\x12\x14\n\x0cpressure_abs\x18\x04 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x05 \x01(\x01\x12\x15\n\rpressure_diff\x18\x06 \x01(\x01\x12\x16\n\x0etrue_air_speed\x18\x07 \x01(\x01\x12\x17\n\x0f\x61ir_temperature\x18\x08 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_air_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SBGAIRDATA']._serialized_start=231
  _globals['_SBGAIRDATA']._serialized_end=517
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RoutePrecondition(_message.Message):
    __slots__ = ["robot_id", "current_route_segment"]
    ROBOT_ID_FIELD_NUMBER: _ClassVar[int]
    CURRENT_ROUTE_SEGMENT_FIELD_NUMBER: _ClassVar[int]
    robot_id: str
    current_route_segment: int
    def __init__(self, robot_id: _Optional[str] = ..., current_route_segment: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.automotive_navigation_msgs.msg import point_of_interest_status_pb2 as _point_of_interest_status_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointOfInterestResponse(_message.Message):
    __slots__ = ["header", "ros2_header", "name", "module_name", "request_id", "update_num", "point_statuses"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATE_NUM_FIELD_NUMBER: _ClassVar[int]
    POINT_STATUSES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    name: str
    module_name: str
    request_id: int
    update_num: int
    point_statuses: _containers.RepeatedCompositeFieldContainer[_point_of_interest_status_pb2.PointOfInterestStatus]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., name: _Optional[str] = ..., module_name: _Optional[str] = ..., request_id: _Optional[int] = ..., update_num: _Optional[int] = ..., point_statuses: _Optional[_Iterable[_Union[_point_of_interest_status_pb2.PointOfInterestStatus, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.micro_ros_diagnostic_msgs.msg import micro_ros_diagnostic_status_pb2 as _micro_ros_diagnostic_status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MicroROSSelfTestRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class MicroROSSelfTestResponse(_message.Message):
    __slots__ = ["id", "passed", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PASSED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    passed: int
    status: _micro_ros_diagnostic_status_pb2.MicroROSDiagnosticStatus
    def __init__(self, id: _Optional[str] = ..., passed: _Optional[int] = ..., status: _Optional[_Union[_micro_ros_diagnostic_status_pb2.MicroROSDiagnosticStatus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/wrapyfi_ros2_interfaces/srv/ros2_audio_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.wrapyfi_ros2_interfaces.msg import ros2_audio_message_pb2 as make87__messages__ros2_dot_humble_dot_wrapyfi__ros2__interfaces_dot_msg_dot_ros2__audio__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/wrapyfi_ros2_interfaces/srv/ros2_audio_service.proto\x12\x37make87_messages_ros2.humble.wrapyfi_ros2_interfaces.srv\x1a!make87_messages/core/header.proto\x1aPmake87_messages_ros2/humble/wrapyfi_ros2_interfaces/msg/ros2_audio_message.proto\"X\n\x17ROS2AudioServiceRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07request\x18\x02 \x01(\t\"\xa5\x01\n\x18ROS2AudioServiceResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12[\n\x08response\x18\x02 \x01(\x0b\x32I.make87_messages_ros2.humble.wrapyfi_ros2_interfaces.msg.ROS2AudioMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.wrapyfi_ros2_interfaces.srv.ros2_audio_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROS2AUDIOSERVICEREQUEST']._serialized_start=258
  _globals['_ROS2AUDIOSERVICEREQUEST']._serialized_end=346
  _globals['_ROS2AUDIOSERVICERESPONSE']._serialized_start=349
  _globals['_ROS2AUDIOSERVICERESPONSE']._serialized_end=514
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelCorrectedImuData(_message.Message):
    __slots__ = ["header", "ros2_header", "novatel_msg_header", "gps_week_num", "gps_seconds", "pitch_rate", "roll_rate", "yaw_rate", "lateral_acceleration", "longitudinal_acceleration", "vertical_acceleration"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    GPS_WEEK_NUM_FIELD_NUMBER: _ClassVar[int]
    GPS_SECONDS_FIELD_NUMBER: _ClassVar[int]
    PITCH_RATE_FIELD_NUMBER: _ClassVar[int]
    ROLL_RATE_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    LATERAL_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    gps_week_num: int
    gps_seconds: float
    pitch_rate: float
    roll_rate: float
    yaw_rate: float
    lateral_acceleration: float
    longitudinal_acceleration: float
    vertical_acceleration: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., gps_week_num: _Optional[int] = ..., gps_seconds: _Optional[float] = ..., pitch_rate: _Optional[float] = ..., roll_rate: _Optional[float] = ..., yaw_rate: _Optional[float] = ..., lateral_acceleration: _Optional[float] = ..., longitudinal_acceleration: _Optional[float] = ..., vertical_acceleration: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import attached_collision_object_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_attached__collision__object__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_joint__state__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import multi_dof_joint_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_multi__dof__joint__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1aJmake87_messages_ros2/jazzy/moveit_msgs/msg/attached_collision_object.proto\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/joint_state.proto\x1a\x46make87_messages_ros2/jazzy/sensor_msgs/msg/multi_dof_joint_state.proto\"\xb2\x02\n\nRobotState\x12K\n\x0bjoint_state\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.JointState\x12]\n\x15multi_dof_joint_state\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.jazzy.sensor_msgs.msg.MultiDOFJointState\x12g\n\x1a\x61ttached_collision_objects\x18\x03 \x03(\x0b\x32\x43.make87_messages_ros2.jazzy.moveit_msgs.msg.AttachedCollisionObject\x12\x0f\n\x07is_diff\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.robot_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROBOTSTATE']._serialized_start=319
  _globals['_ROBOTSTATE']._serialized_end=625
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.gazebo_msgs.msg import ode_joint_properties_pb2 as _ode_joint_properties_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetJointPropertiesRequest(_message.Message):
    __slots__ = ["joint_name", "ode_joint_config"]
    JOINT_NAME_FIELD_NUMBER: _ClassVar[int]
    ODE_JOINT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    joint_name: str
    ode_joint_config: _ode_joint_properties_pb2.ODEJointProperties
    def __init__(self, joint_name: _Optional[str] = ..., ode_joint_config: _Optional[_Union[_ode_joint_properties_pb2.ODEJointProperties, _Mapping]] = ...) -> None: ...

class SetJointPropertiesResponse(_message.Message):
    __slots__ = ["success", "status_message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status_message: str
    def __init__(self, success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EsfMEAS(_message.Message):
    __slots__ = ["time_tag", "flags", "id", "data", "calib_t_tag"]
    TIME_TAG_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    CALIB_T_TAG_FIELD_NUMBER: _ClassVar[int]
    time_tag: int
    flags: int
    id: int
    data: _containers.RepeatedScalarFieldContainer[int]
    calib_t_tag: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, time_tag: _Optional[int] = ..., flags: _Optional[int] = ..., id: _Optional[int] = ..., data: _Optional[_Iterable[int]] = ..., calib_t_tag: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_scheduler_msgs/srv/list_schedule_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_scheduler_msgs.msg import schedule_state_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__scheduler__msgs_dot_msg_dot_schedule__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/rmf_scheduler_msgs/srv/list_schedule_states.proto\x12\x33make87_messages_ros2.rolling.rmf_scheduler_msgs.srv\x1aHmake87_messages_ros2/rolling/rmf_scheduler_msgs/msg/schedule_state.proto\"3\n\x19ListScheduleStatesRequest\x12\x16\n\x0emodified_after\x18\x01 \x01(\x03\"\x95\x01\n\x1aListScheduleStatesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12U\n\tschedules\x18\x03 \x03(\x0b\x32\x42.make87_messages_ros2.rolling.rmf_scheduler_msgs.msg.ScheduleStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_scheduler_msgs.srv.list_schedule_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LISTSCHEDULESTATESREQUEST']._serialized_start=209
  _globals['_LISTSCHEDULESTATESREQUEST']._serialized_end=260
  _globals['_LISTSCHEDULESTATESRESPONSE']._serialized_start=263
  _globals['_LISTSCHEDULESTATESRESPONSE']._serialized_end=412
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.fuse_msgs.msg import serialized_graph_pb2 as _serialized_graph_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetGraphRequest(_message.Message):
    __slots__ = ["graph"]
    GRAPH_FIELD_NUMBER: _ClassVar[int]
    graph: _serialized_graph_pb2.SerializedGraph
    def __init__(self, graph: _Optional[_Union[_serialized_graph_pb2.SerializedGraph, _Mapping]] = ...) -> None: ...

class SetGraphResponse(_message.Message):
    __slots__ = ["success", "message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/vehicle_info_get.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.mavros_msgs.msg import vehicle_info_pb2 as make87__messages__ros2_dot_jazzy_dot_mavros__msgs_dot_msg_dot_vehicle__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/mavros_msgs/srv/vehicle_info_get.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\x1a=make87_messages_ros2/jazzy/mavros_msgs/msg/vehicle_info.proto\"G\n\x15VehicleInfoGetRequest\x12\r\n\x05sysid\x18\x01 \x01(\r\x12\x0e\n\x06\x63ompid\x18\x02 \x01(\r\x12\x0f\n\x07get_all\x18\x03 \x01(\x08\"t\n\x16VehicleInfoGetResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12I\n\x08vehicles\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.mavros_msgs.msg.VehicleInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.vehicle_info_get_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_VEHICLEINFOGETREQUEST']._serialized_start=176
  _globals['_VEHICLEINFOGETREQUEST']._serialized_end=247
  _globals['_VEHICLEINFOGETRESPONSE']._serialized_start=249
  _globals['_VEHICLEINFOGETRESPONSE']._serialized_end=365
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.type_description_interfaces.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.rolling.type_description_interfaces.msg import type_description_pb2 as _type_description_pb2
from make87_messages_ros2.rolling.type_description_interfaces.msg import type_source_pb2 as _type_source_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTypeDescriptionRequest(_message.Message):
    __slots__ = ["type_name", "type_hash", "include_type_sources"]
    TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_HASH_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_TYPE_SOURCES_FIELD_NUMBER: _ClassVar[int]
    type_name: str
    type_hash: str
    include_type_sources: bool
    def __init__(self, type_name: _Optional[str] = ..., type_hash: _Optional[str] = ..., include_type_sources: bool = ...) -> None: ...

class GetTypeDescriptionResponse(_message.Message):
    __slots__ = ["successful", "failure_reason", "type_description", "type_sources", "extra_information"]
    SUCCESSFUL_FIELD_NUMBER: _ClassVar[int]
    FAILURE_REASON_FIELD_NUMBER: _ClassVar[int]
    TYPE_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_SOURCES_FIELD_NUMBER: _ClassVar[int]
    EXTRA_INFORMATION_FIELD_NUMBER: _ClassVar[int]
    successful: bool
    failure_reason: str
    type_description: _type_description_pb2.TypeDescription
    type_sources: _containers.RepeatedCompositeFieldContainer[_type_source_pb2.TypeSource]
    extra_information: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, successful: bool = ..., failure_reason: _Optional[str] = ..., type_description: _Optional[_Union[_type_description_pb2.TypeDescription, _Mapping]] = ..., type_sources: _Optional[_Iterable[_Union[_type_source_pb2.TypeSource, _Mapping]]] = ..., extra_information: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_scheduler_msgs.msg import payload_pb2 as _payload_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Trigger(_message.Message):
    __slots__ = ["name", "created_at", "at", "group", "payload"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    AT_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    name: str
    created_at: int
    at: int
    group: str
    payload: _payload_pb2.Payload
    def __init__(self, name: _Optional[str] = ..., created_at: _Optional[int] = ..., at: _Optional[int] = ..., group: _Optional[str] = ..., payload: _Optional[_Union[_payload_pb2.Payload, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.lifecycle_msgs.msg import state_pb2 as _state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetStateRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetStateResponse(_message.Message):
    __slots__ = ["current_state"]
    CURRENT_STATE_FIELD_NUMBER: _ClassVar[int]
    current_state: _state_pb2.State
    def __init__(self, current_state: _Optional[_Union[_state_pb2.State, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/micro_ros_msgs/msg/node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.micro_ros_msgs.msg import entity_pb2 as make87__messages__ros2_dot_jazzy_dot_micro__ros__msgs_dot_msg_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/micro_ros_msgs/msg/node.proto\x12-make87_messages_ros2.jazzy.micro_ros_msgs.msg\x1a:make87_messages_ros2/jazzy/micro_ros_msgs/msg/entity.proto\"z\n\x04Node\x12\x16\n\x0enode_namespace\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12G\n\x08\x65ntities\x18\x03 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.micro_ros_msgs.msg.Entityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.micro_ros_msgs.msg.node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NODE']._serialized_start=167
  _globals['_NODE']._serialized_end=289
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviorModification(_message.Message):
    __slots__ = ["header", "index_begin", "index_end", "new_content"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INDEX_BEGIN_FIELD_NUMBER: _ClassVar[int]
    INDEX_END_FIELD_NUMBER: _ClassVar[int]
    NEW_CONTENT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    index_begin: int
    index_end: int
    new_content: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., index_begin: _Optional[int] = ..., index_end: _Optional[int] = ..., new_content: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as _transform_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Link(_message.Message):
    __slots__ = ["header", "from_id", "to_id", "type", "transform", "information"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FROM_ID_FIELD_NUMBER: _ClassVar[int]
    TO_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    INFORMATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    from_id: int
    to_id: int
    type: int
    transform: _transform_pb2.Transform
    information: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., from_id: _Optional[int] = ..., to_id: _Optional[int] = ..., type: _Optional[int] = ..., transform: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., information: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/octomap_msgs/srv/get_octomap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.octomap_msgs.msg import octomap_pb2 as make87__messages__ros2_dot_rolling_dot_octomap__msgs_dot_msg_dot_octomap__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/octomap_msgs/srv/get_octomap.proto\x12-make87_messages_ros2.rolling.octomap_msgs.srv\x1a;make87_messages_ros2/rolling/octomap_msgs/msg/octomap.proto\"\x13\n\x11GetOctomapRequest\"Y\n\x12GetOctomapResponse\x12\x43\n\x03map\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.octomap_msgs.msg.Octomapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.octomap_msgs.srv.get_octomap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETOCTOMAPREQUEST']._serialized_start=175
  _globals['_GETOCTOMAPREQUEST']._serialized_end=194
  _globals['_GETOCTOMAPRESPONSE']._serialized_start=196
  _globals['_GETOCTOMAPRESPONSE']._serialized_end=285
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ["header", "id", "instance_id", "active", "heartbeat_timeout", "heartbeat_period"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_PERIOD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: str
    instance_id: str
    active: bool
    heartbeat_timeout: float
    heartbeat_period: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[str] = ..., instance_id: _Optional[str] = ..., active: bool = ..., heartbeat_timeout: _Optional[float] = ..., heartbeat_period: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/object_recognition_msgs/srv/get_object_information.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.object_recognition_msgs.msg import object_information_pb2 as make87__messages__ros2_dot_jazzy_dot_object__recognition__msgs_dot_msg_dot_object__information__pb2
from make87_messages_ros2.jazzy.object_recognition_msgs.msg import object_type_pb2 as make87__messages__ros2_dot_jazzy_dot_object__recognition__msgs_dot_msg_dot_object__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/jazzy/object_recognition_msgs/srv/get_object_information.proto\x12\x36make87_messages_ros2.jazzy.object_recognition_msgs.srv\x1aOmake87_messages_ros2/jazzy/object_recognition_msgs/msg/object_information.proto\x1aHmake87_messages_ros2/jazzy/object_recognition_msgs/msg/object_type.proto\"o\n\x1bGetObjectInformationRequest\x12P\n\x04type\x18\x01 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.object_recognition_msgs.msg.ObjectType\"~\n\x1cGetObjectInformationResponse\x12^\n\x0binformation\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.jazzy.object_recognition_msgs.msg.ObjectInformationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.object_recognition_msgs.srv.get_object_information_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETOBJECTINFORMATIONREQUEST']._serialized_start=298
  _globals['_GETOBJECTINFORMATIONREQUEST']._serialized_end=409
  _globals['_GETOBJECTINFORMATIONRESPONSE']._serialized_start=411
  _globals['_GETOBJECTINFORMATIONRESPONSE']._serialized_end=537
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.moveit_msgs.msg import planning_scene_pb2 as _planning_scene_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlanningOptions(_message.Message):
    __slots__ = ["planning_scene_diff", "plan_only", "look_around", "look_around_attempts", "max_safe_execution_cost", "replan", "replan_attempts", "replan_delay"]
    PLANNING_SCENE_DIFF_FIELD_NUMBER: _ClassVar[int]
    PLAN_ONLY_FIELD_NUMBER: _ClassVar[int]
    LOOK_AROUND_FIELD_NUMBER: _ClassVar[int]
    LOOK_AROUND_ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
    MAX_SAFE_EXECUTION_COST_FIELD_NUMBER: _ClassVar[int]
    REPLAN_FIELD_NUMBER: _ClassVar[int]
    REPLAN_ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
    REPLAN_DELAY_FIELD_NUMBER: _ClassVar[int]
    planning_scene_diff: _planning_scene_pb2.PlanningScene
    plan_only: bool
    look_around: bool
    look_around_attempts: int
    max_safe_execution_cost: float
    replan: bool
    replan_attempts: int
    replan_delay: float
    def __init__(self, planning_scene_diff: _Optional[_Union[_planning_scene_pb2.PlanningScene, _Mapping]] = ..., plan_only: bool = ..., look_around: bool = ..., look_around_attempts: _Optional[int] = ..., max_safe_execution_cost: _Optional[float] = ..., replan: bool = ..., replan_attempts: _Optional[int] = ..., replan_delay: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/create_msgs/msg/bumper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/humble/create_msgs/msg/bumper.proto\x12+make87_messages_ros2.humble.create_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x96\x04\n\x06\x42umper\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x17\n\x0fis_left_pressed\x18\x03 \x01(\x08\x12\x18\n\x10is_right_pressed\x18\x04 \x01(\x08\x12\x15\n\ris_light_left\x18\x05 \x01(\x08\x12\x1b\n\x13is_light_front_left\x18\x06 \x01(\x08\x12\x1c\n\x14is_light_center_left\x18\x07 \x01(\x08\x12\x1d\n\x15is_light_center_right\x18\x08 \x01(\x08\x12\x1c\n\x14is_light_front_right\x18\t \x01(\x08\x12\x16\n\x0eis_light_right\x18\n \x01(\x08\x12\x19\n\x11light_signal_left\x18\x0b \x01(\r\x12\x1f\n\x17light_signal_front_left\x18\x0c \x01(\r\x12 \n\x18light_signal_center_left\x18\r \x01(\r\x12!\n\x19light_signal_center_right\x18\x0e \x01(\r\x12 \n\x18light_signal_front_right\x18\x0f \x01(\r\x12\x1a\n\x12light_signal_right\x18\x10 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.create_msgs.msg.bumper_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BUMPER']._serialized_start=196
  _globals['_BUMPER']._serialized_end=730
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccContainerStructure(_message.Message):
    __slots__ = ["header", "path", "children", "internal_outcomes", "outcomes_from", "outcomes_to", "container_outcomes"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_OUTCOMES_FIELD_NUMBER: _ClassVar[int]
    OUTCOMES_FROM_FIELD_NUMBER: _ClassVar[int]
    OUTCOMES_TO_FIELD_NUMBER: _ClassVar[int]
    CONTAINER_OUTCOMES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    path: str
    children: _containers.RepeatedScalarFieldContainer[str]
    internal_outcomes: _containers.RepeatedScalarFieldContainer[str]
    outcomes_from: _containers.RepeatedScalarFieldContainer[str]
    outcomes_to: _containers.RepeatedScalarFieldContainer[str]
    container_outcomes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., path: _Optional[str] = ..., children: _Optional[_Iterable[str]] = ..., internal_outcomes: _Optional[_Iterable[str]] = ..., outcomes_from: _Optional[_Iterable[str]] = ..., outcomes_to: _Optional[_Iterable[str]] = ..., container_outcomes: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as _twist_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as _wrench_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetForceModeRequest(_message.Message):
    __slots__ = ["task_frame", "selection_vector_x", "selection_vector_y", "selection_vector_z", "selection_vector_rx", "selection_vector_ry", "selection_vector_rz", "wrench", "type", "speed_limits", "deviation_limits", "damping_factor", "gain_scaling"]
    TASK_FRAME_FIELD_NUMBER: _ClassVar[int]
    SELECTION_VECTOR_X_FIELD_NUMBER: _ClassVar[int]
    SELECTION_VECTOR_Y_FIELD_NUMBER: _ClassVar[int]
    SELECTION_VECTOR_Z_FIELD_NUMBER: _ClassVar[int]
    SELECTION_VECTOR_RX_FIELD_NUMBER: _ClassVar[int]
    SELECTION_VECTOR_RY_FIELD_NUMBER: _ClassVar[int]
    SELECTION_VECTOR_RZ_FIELD_NUMBER: _ClassVar[int]
    WRENCH_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SPEED_LIMITS_FIELD_NUMBER: _ClassVar[int]
    DEVIATION_LIMITS_FIELD_NUMBER: _ClassVar[int]
    DAMPING_FACTOR_FIELD_NUMBER: _ClassVar[int]
    GAIN_SCALING_FIELD_NUMBER: _ClassVar[int]
    task_frame: _pose_stamped_pb2.PoseStamped
    selection_vector_x: bool
    selection_vector_y: bool
    selection_vector_z: bool
    selection_vector_rx: bool
    selection_vector_ry: bool
    selection_vector_rz: bool
    wrench: _wrench_pb2.Wrench
    type: int
    speed_limits: _twist_pb2.Twist
    deviation_limits: _containers.RepeatedScalarFieldContainer[float]
    damping_factor: float
    gain_scaling: float
    def __init__(self, task_frame: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., selection_vector_x: bool = ..., selection_vector_y: bool = ..., selection_vector_z: bool = ..., selection_vector_rx: bool = ..., selection_vector_ry: bool = ..., selection_vector_rz: bool = ..., wrench: _Optional[_Union[_wrench_pb2.Wrench, _Mapping]] = ..., type: _Optional[int] = ..., speed_limits: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ..., deviation_limits: _Optional[_Iterable[float]] = ..., damping_factor: _Optional[float] = ..., gain_scaling: _Optional[float] = ...) -> None: ...

class SetForceModeResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/msg/entity_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_twist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/gazebo_msgs/msg/entity_state.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/twist.proto\"\xba\x01\n\x0b\x45ntityState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x04pose\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x42\n\x05twist\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Twist\x12\x17\n\x0freference_frame\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.msg.entity_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ENTITYSTATE']._serialized_start=225
  _globals['_ENTITYSTATE']._serialized_end=411
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/delphi_esr_msgs/msg/esr_status2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/delphi_esr_msgs/msg/esr_status2.proto\x12.make87_messages_ros2.jazzy.delphi_esr_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xa1\x03\n\nEsrStatus2\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0e\n\x06\x63\x61nmsg\x18\x02 \x01(\t\x12\x1a\n\x12maximum_tracks_ack\x18\x03 \x01(\r\x12\x17\n\x0frolling_count_2\x18\x04 \x01(\r\x12\x16\n\x0eoverheat_error\x18\x05 \x01(\x08\x12\x18\n\x10range_perf_error\x18\x06 \x01(\x08\x12\x16\n\x0einternal_error\x18\x07 \x01(\x08\x12\x18\n\x10xcvr_operational\x18\x08 \x01(\x08\x12\x15\n\rraw_data_mode\x18\t \x01(\x08\x12\x1a\n\x12steering_angle_ack\x18\n \x01(\r\x12\x13\n\x0btemperature\x18\x0b \x01(\x05\x12\x1b\n\x13veh_spd_comp_factor\x18\x0c \x01(\x02\x12\x15\n\rgrouping_mode\x18\r \x01(\r\x12\x15\n\ryaw_rate_bias\x18\x0e \x01(\x02\x12\x16\n\x0esw_version_dsp\x18\x0f \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.delphi_esr_msgs.msg.esr_status2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ESRSTATUS2']._serialized_start=171
  _globals['_ESRSTATUS2']._serialized_end=588
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/trackstat_channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/novatel_gps_msgs/msg/trackstat_channel.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\"\xb9\x01\n\x10TrackstatChannel\x12\x0b\n\x03prn\x18\x01 \x01(\x05\x12\x0f\n\x07glofreq\x18\x02 \x01(\x05\x12\x14\n\x0c\x63h_tr_status\x18\x03 \x01(\r\x12\x0b\n\x03psr\x18\x04 \x01(\x01\x12\x0f\n\x07\x64oppler\x18\x05 \x01(\x02\x12\x0c\n\x04\x63_no\x18\x06 \x01(\x02\x12\x10\n\x08locktime\x18\x07 \x01(\x02\x12\x0f\n\x07psr_res\x18\x08 \x01(\x02\x12\x0e\n\x06reject\x18\t \x01(\t\x12\x12\n\npsr_weight\x18\n \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.trackstat_channel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRACKSTATCHANNEL']._serialized_start=129
  _globals['_TRACKSTATCHANNEL']._serialized_end=314
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import transform_pb2 as _transform_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransformStamped(_message.Message):
    __slots__ = ["header", "child_frame_id", "transform"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CHILD_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    child_frame_id: str
    transform: _transform_pb2.Transform
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., child_frame_id: _Optional[str] = ..., transform: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/robot_localization/srv/set_datum.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import geo_pose_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_geo__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/robot_localization/srv/set_datum.proto\x12\x33make87_messages_ros2.rolling.robot_localization.srv\x1a?make87_messages_ros2/rolling/geographic_msgs/msg/geo_pose.proto\"^\n\x0fSetDatumRequest\x12K\n\x08geo_pose\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.geographic_msgs.msg.GeoPose\"\x12\n\x10SetDatumResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.robot_localization.srv.set_datum_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETDATUMREQUEST']._serialized_start=189
  _globals['_SETDATUMREQUEST']._serialized_end=283
  _globals['_SETDATUMRESPONSE']._serialized_start=285
  _globals['_SETDATUMRESPONSE']._serialized_end=303
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/srv/gimbal_manager_camera_track.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/jazzy/mavros_msgs/srv/gimbal_manager_camera_track.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.srv\"\xad\x01\n\x1fGimbalManagerCameraTrackRequest\x12\x0c\n\x04mode\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\x0e\n\x06radius\x18\x04 \x01(\x02\x12\x12\n\ntop_left_x\x18\x05 \x01(\x02\x12\x12\n\ntop_left_y\x18\x06 \x01(\x02\x12\x16\n\x0e\x62ottom_right_x\x18\x07 \x01(\x02\x12\x16\n\x0e\x62ottom_right_y\x18\x08 \x01(\x02\"C\n GimbalManagerCameraTrackResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.srv.gimbal_manager_camera_track_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERCAMERATRACKREQUEST']._serialized_start=125
  _globals['_GIMBALMANAGERCAMERATRACKREQUEST']._serialized_end=298
  _globals['_GIMBALMANAGERCAMERATRACKRESPONSE']._serialized_start=300
  _globals['_GIMBALMANAGERCAMERATRACKRESPONSE']._serialized_end=367
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_log.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_log.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.msg\"0\n\x0b\x42\x65haviorLog\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.msg.behavior_log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIORLOG']._serialized_start=109
  _globals['_BEHAVIORLOG']._serialized_end=157
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VersionInfo(_message.Message):
    __slots__ = ["header", "hardware", "firmware", "software"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    hardware: str
    firmware: str
    software: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., hardware: _Optional[str] = ..., firmware: _Optional[str] = ..., software: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as _move_it_error_codes_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPositionFKRequest(_message.Message):
    __slots__ = ["header", "fk_link_names", "robot_state"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FK_LINK_NAMES_FIELD_NUMBER: _ClassVar[int]
    ROBOT_STATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fk_link_names: _containers.RepeatedScalarFieldContainer[str]
    robot_state: _robot_state_pb2.RobotState
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fk_link_names: _Optional[_Iterable[str]] = ..., robot_state: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ...) -> None: ...

class GetPositionFKResponse(_message.Message):
    __slots__ = ["pose_stamped", "fk_link_names", "error_code"]
    POSE_STAMPED_FIELD_NUMBER: _ClassVar[int]
    FK_LINK_NAMES_FIELD_NUMBER: _ClassVar[int]
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    pose_stamped: _containers.RepeatedCompositeFieldContainer[_pose_stamped_pb2.PoseStamped]
    fk_link_names: _containers.RepeatedScalarFieldContainer[str]
    error_code: _move_it_error_codes_pb2.MoveItErrorCodes
    def __init__(self, pose_stamped: _Optional[_Iterable[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]]] = ..., fk_link_names: _Optional[_Iterable[str]] = ..., error_code: _Optional[_Union[_move_it_error_codes_pb2.MoveItErrorCodes, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_task_msgs/msg/task_profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import task_description_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_task__description__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rmf_task_msgs/msg/task_profile.proto\x12.make87_messages_ros2.rolling.rmf_task_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x45make87_messages_ros2/rolling/rmf_task_msgs/msg/task_description.proto\"\xc8\x01\n\x0bTaskProfile\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12R\n\x0fsubmission_time\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12T\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32?.make87_messages_ros2.rolling.rmf_task_msgs.msg.TaskDescriptionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_task_msgs.msg.task_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TASKPROFILE']._serialized_start=253
  _globals['_TASKPROFILE']._serialized_end=453
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LiftState(_message.Message):
    __slots__ = ["lift_time", "lift_name", "available_floors", "current_floor", "destination_floor", "door_state", "motion_state", "available_modes", "current_mode", "session_id"]
    LIFT_TIME_FIELD_NUMBER: _ClassVar[int]
    LIFT_NAME_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_FLOORS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FLOOR_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_FLOOR_FIELD_NUMBER: _ClassVar[int]
    DOOR_STATE_FIELD_NUMBER: _ClassVar[int]
    MOTION_STATE_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_MODES_FIELD_NUMBER: _ClassVar[int]
    CURRENT_MODE_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    lift_time: _time_pb2.Time
    lift_name: str
    available_floors: _containers.RepeatedScalarFieldContainer[str]
    current_floor: str
    destination_floor: str
    door_state: int
    motion_state: int
    available_modes: _containers.RepeatedScalarFieldContainer[int]
    current_mode: int
    session_id: str
    def __init__(self, lift_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., lift_name: _Optional[str] = ..., available_floors: _Optional[_Iterable[str]] = ..., current_floor: _Optional[str] = ..., destination_floor: _Optional[str] = ..., door_state: _Optional[int] = ..., motion_state: _Optional[int] = ..., available_modes: _Optional[_Iterable[int]] = ..., current_mode: _Optional[int] = ..., session_id: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.rolling.marker_msgs.msg import marker_pb2 as _marker_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MarkerDetection(_message.Message):
    __slots__ = ["header", "distance_min", "distance_max", "distance_max_id", "view_direction", "fov_horizontal", "fov_vertical", "type", "markers"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_MIN_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_MAX_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_MAX_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    FOV_HORIZONTAL_FIELD_NUMBER: _ClassVar[int]
    FOV_VERTICAL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    MARKERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    distance_min: float
    distance_max: float
    distance_max_id: float
    view_direction: _quaternion_pb2.Quaternion
    fov_horizontal: float
    fov_vertical: float
    type: str
    markers: _containers.RepeatedCompositeFieldContainer[_marker_pb2.Marker]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., distance_min: _Optional[float] = ..., distance_max: _Optional[float] = ..., distance_max_id: _Optional[float] = ..., view_direction: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., fov_horizontal: _Optional[float] = ..., fov_vertical: _Optional[float] = ..., type: _Optional[str] = ..., markers: _Optional[_Iterable[_Union[_marker_pb2.Marker, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import clean_pb2 as _clean_pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import delivery_pb2 as _delivery_pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import loop_pb2 as _loop_pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import priority_pb2 as _priority_pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import station_pb2 as _station_pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import task_type_pb2 as _task_type_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TaskDescription(_message.Message):
    __slots__ = ["start_time", "priority", "task_type", "station", "loop", "delivery", "clean"]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    TASK_TYPE_FIELD_NUMBER: _ClassVar[int]
    STATION_FIELD_NUMBER: _ClassVar[int]
    LOOP_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_FIELD_NUMBER: _ClassVar[int]
    CLEAN_FIELD_NUMBER: _ClassVar[int]
    start_time: _time_pb2.Time
    priority: _priority_pb2.Priority
    task_type: _task_type_pb2.TaskType
    station: _station_pb2.Station
    loop: _loop_pb2.Loop
    delivery: _delivery_pb2.Delivery
    clean: _clean_pb2.Clean
    def __init__(self, start_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., priority: _Optional[_Union[_priority_pb2.Priority, _Mapping]] = ..., task_type: _Optional[_Union[_task_type_pb2.TaskType, _Mapping]] = ..., station: _Optional[_Union[_station_pb2.Station, _Mapping]] = ..., loop: _Optional[_Union[_loop_pb2.Loop, _Mapping]] = ..., delivery: _Optional[_Union[_delivery_pb2.Delivery, _Mapping]] = ..., clean: _Optional[_Union[_clean_pb2.Clean, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/complex_srv_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg import basic_msg_pb2 as make87__messages__ros2_dot_jazzy_dot_rosbag2__test__msgdefs_dot_msg_dot_basic__msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/rosbag2_test_msgdefs/srv/complex_srv_msg.proto\x12\x33make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv\x1a\x43make87_messages_ros2/jazzy/rosbag2_test_msgdefs/msg/basic_msg.proto\"b\n\x14\x43omplexSrvMsgRequest\x12J\n\x03req\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg.BasicMsg\"d\n\x15\x43omplexSrvMsgResponse\x12K\n\x04resp\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg.BasicMsgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rosbag2_test_msgdefs.srv.complex_srv_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPLEXSRVMSGREQUEST']._serialized_start=199
  _globals['_COMPLEXSRVMSGREQUEST']._serialized_end=297
  _globals['_COMPLEXSRVMSGRESPONSE']._serialized_start=299
  _globals['_COMPLEXSRVMSGRESPONSE']._serialized_end=399
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import object_classification_pb2 as _object_classification_pb2
from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import predicted_object_kinematics_pb2 as _predicted_object_kinematics_pb2
from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import shape_pb2 as _shape_pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PredictedObject(_message.Message):
    __slots__ = ["object_id", "existence_probability", "classification", "kinematics", "shape"]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    EXISTENCE_PROBABILITY_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    KINEMATICS_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    object_id: _uuid_pb2.UUID
    existence_probability: float
    classification: _containers.RepeatedCompositeFieldContainer[_object_classification_pb2.ObjectClassification]
    kinematics: _predicted_object_kinematics_pb2.PredictedObjectKinematics
    shape: _shape_pb2.Shape
    def __init__(self, object_id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., existence_probability: _Optional[float] = ..., classification: _Optional[_Iterable[_Union[_object_classification_pb2.ObjectClassification, _Mapping]]] = ..., kinematics: _Optional[_Union[_predicted_object_kinematics_pb2.PredictedObjectKinematics, _Mapping]] = ..., shape: _Optional[_Union[_shape_pb2.Shape, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_pb2 as _parameter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LoadNodeRequest(_message.Message):
    __slots__ = ["package_name", "plugin_name", "node_name", "node_namespace", "log_level", "remap_rules", "parameters", "extra_arguments"]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    PLUGIN_NAME_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    NODE_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    LOG_LEVEL_FIELD_NUMBER: _ClassVar[int]
    REMAP_RULES_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    package_name: str
    plugin_name: str
    node_name: str
    node_namespace: str
    log_level: int
    remap_rules: _containers.RepeatedScalarFieldContainer[str]
    parameters: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    extra_arguments: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    def __init__(self, package_name: _Optional[str] = ..., plugin_name: _Optional[str] = ..., node_name: _Optional[str] = ..., node_namespace: _Optional[str] = ..., log_level: _Optional[int] = ..., remap_rules: _Optional[_Iterable[str]] = ..., parameters: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ..., extra_arguments: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ...) -> None: ...

class LoadNodeResponse(_message.Message):
    __slots__ = ["success", "error_message", "full_node_name", "unique_id"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    FULL_NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    full_node_name: str
    unique_id: int
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ..., full_node_name: _Optional[str] = ..., unique_id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/pcl_msgs/msg/polygon_mesh.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.pcl_msgs.msg import vertices_pb2 as make87__messages__ros2_dot_rolling_dot_pcl__msgs_dot_msg_dot_vertices__pb2
from make87_messages_ros2.rolling.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_rolling_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/pcl_msgs/msg/polygon_mesh.proto\x12)make87_messages_ros2.rolling.pcl_msgs.msg\x1a\x38make87_messages_ros2/rolling/pcl_msgs/msg/vertices.proto\x1a?make87_messages_ros2/rolling/sensor_msgs/msg/point_cloud2.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xe1\x01\n\x0bPolygonMesh\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12H\n\x05\x63loud\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.sensor_msgs.msg.PointCloud2\x12\x45\n\x08polygons\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.pcl_msgs.msg.Verticesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.pcl_msgs.msg.polygon_mesh_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POLYGONMESH']._serialized_start=287
  _globals['_POLYGONMESH']._serialized_end=512
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/controller_manager_msgs/srv/list_hardware_interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.controller_manager_msgs.msg import hardware_interface_pb2 as make87__messages__ros2_dot_rolling_dot_controller__manager__msgs_dot_msg_dot_hardware__interface__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/rolling/controller_manager_msgs/srv/list_hardware_interfaces.proto\x12\x38make87_messages_ros2.rolling.controller_manager_msgs.srv\x1aQmake87_messages_ros2/rolling/controller_manager_msgs/msg/hardware_interface.proto\"\x1f\n\x1dListHardwareInterfacesRequest\"\xf0\x01\n\x1eListHardwareInterfacesResponse\x12g\n\x12\x63ommand_interfaces\x18\x01 \x03(\x0b\x32K.make87_messages_ros2.rolling.controller_manager_msgs.msg.HardwareInterface\x12\x65\n\x10state_interfaces\x18\x02 \x03(\x0b\x32K.make87_messages_ros2.rolling.controller_manager_msgs.msg.HardwareInterfaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.controller_manager_msgs.srv.list_hardware_interfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LISTHARDWAREINTERFACESREQUEST']._serialized_start=232
  _globals['_LISTHARDWAREINTERFACESREQUEST']._serialized_end=263
  _globals['_LISTHARDWAREINTERFACESRESPONSE']._serialized_start=266
  _globals['_LISTHARDWAREINTERFACESRESPONSE']._serialized_end=506
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.plansys2_msgs.msg import derived_pb2 as _derived_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDomainDerivedPredicateDetailsRequest(_message.Message):
    __slots__ = ["predicate"]
    PREDICATE_FIELD_NUMBER: _ClassVar[int]
    predicate: str
    def __init__(self, predicate: _Optional[str] = ...) -> None: ...

class GetDomainDerivedPredicateDetailsResponse(_message.Message):
    __slots__ = ["predicates", "success", "error_info"]
    PREDICATES_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    predicates: _containers.RepeatedCompositeFieldContainer[_derived_pb2.Derived]
    success: bool
    error_info: str
    def __init__(self, predicates: _Optional[_Iterable[_Union[_derived_pb2.Derived, _Mapping]]] = ..., success: bool = ..., error_info: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/septentrio_gnss_driver/msg/meas_epoch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import block_header_pb2 as make87__messages__ros2_dot_humble_dot_septentrio__gnss__driver_dot_msg_dot_block__header__pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import meas_epoch_channel_type1_pb2 as make87__messages__ros2_dot_humble_dot_septentrio__gnss__driver_dot_msg_dot_meas__epoch__channel__type1__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/septentrio_gnss_driver/msg/meas_epoch.proto\x12\x36make87_messages_ros2.humble.septentrio_gnss_driver.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/septentrio_gnss_driver/msg/block_header.proto\x1aUmake87_messages_ros2/humble/septentrio_gnss_driver/msg/meas_epoch_channel_type1.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x99\x03\n\tMeasEpoch\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12Y\n\x0c\x62lock_header\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.humble.septentrio_gnss_driver.msg.BlockHeader\x12\t\n\x01n\x18\x04 \x01(\r\x12\x12\n\nsb1_length\x18\x05 \x01(\r\x12\x12\n\nsb2_length\x18\x06 \x01(\r\x12\x14\n\x0c\x63ommon_flags\x18\x07 \x01(\r\x12\x15\n\rcum_clk_jumps\x18\x08 \x01(\r\x12\\\n\x05type1\x18\t \x03(\x0b\x32M.make87_messages_ros2.humble.septentrio_gnss_driver.msg.MeasEpochChannelType1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.septentrio_gnss_driver.msg.meas_epoch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MEASEPOCH']._serialized_start=384
  _globals['_MEASEPOCH']._serialized_end=793
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.vision_msgs.msg import pose2_d_pb2 as _pose2_d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BoundingBox2D(_message.Message):
    __slots__ = ["center", "size_x", "size_y"]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    SIZE_X_FIELD_NUMBER: _ClassVar[int]
    SIZE_Y_FIELD_NUMBER: _ClassVar[int]
    center: _pose2_d_pb2.Pose2D
    size_x: float
    size_y: float
    def __init__(self, center: _Optional[_Union[_pose2_d_pb2.Pose2D, _Mapping]] = ..., size_x: _Optional[float] = ..., size_y: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.statistics_msgs.msg import statistic_data_point_pb2 as _statistic_data_point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MetricsMessage(_message.Message):
    __slots__ = ["measurement_source_name", "metrics_source", "unit", "window_start", "window_stop", "statistics"]
    MEASUREMENT_SOURCE_NAME_FIELD_NUMBER: _ClassVar[int]
    METRICS_SOURCE_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    WINDOW_START_FIELD_NUMBER: _ClassVar[int]
    WINDOW_STOP_FIELD_NUMBER: _ClassVar[int]
    STATISTICS_FIELD_NUMBER: _ClassVar[int]
    measurement_source_name: str
    metrics_source: str
    unit: str
    window_start: _time_pb2.Time
    window_stop: _time_pb2.Time
    statistics: _containers.RepeatedCompositeFieldContainer[_statistic_data_point_pb2.StatisticDataPoint]
    def __init__(self, measurement_source_name: _Optional[str] = ..., metrics_source: _Optional[str] = ..., unit: _Optional[str] = ..., window_start: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., window_stop: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., statistics: _Optional[_Iterable[_Union[_statistic_data_point_pb2.StatisticDataPoint, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import accel_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_accel__with__covariance__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object_kinematics.proto\x12\x39make87_messages_ros2.rolling.autoware_perception_msgs.msg\x1aJmake87_messages_ros2/rolling/geometry_msgs/msg/accel_with_covariance.proto\x1aImake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance.proto\x1aJmake87_messages_ros2/rolling/geometry_msgs/msg/twist_with_covariance.proto\"\x83\x03\n\x17TrackedObjectKinematics\x12`\n\x14pose_with_covariance\x18\x01 \x01(\x0b\x32\x42.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovariance\x12\x62\n\x15twist_with_covariance\x18\x02 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.geometry_msgs.msg.TwistWithCovariance\x12i\n\x1c\x61\x63\x63\x65leration_with_covariance\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.geometry_msgs.msg.AccelWithCovariance\x12 \n\x18orientation_availability\x18\x04 \x01(\r\x12\x15\n\ris_stationary\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_perception_msgs.msg.tracked_object_kinematics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECTKINEMATICS']._serialized_start=380
  _globals['_TRACKEDOBJECTKINEMATICS']._serialized_end=767
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccEventGenerator(_message.Message):
    __slots__ = ["index", "type_name", "object_tag"]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TAG_FIELD_NUMBER: _ClassVar[int]
    index: int
    type_name: str
    object_tag: str
    def __init__(self, index: _Optional[int] = ..., type_name: _Optional[str] = ..., object_tag: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.moveit_msgs.msg import planning_scene_pb2 as _planning_scene_pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import planning_scene_components_pb2 as _planning_scene_components_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPlanningSceneRequest(_message.Message):
    __slots__ = ["components"]
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    components: _planning_scene_components_pb2.PlanningSceneComponents
    def __init__(self, components: _Optional[_Union[_planning_scene_components_pb2.PlanningSceneComponents, _Mapping]] = ...) -> None: ...

class GetPlanningSceneResponse(_message.Message):
    __slots__ = ["scene"]
    SCENE_FIELD_NUMBER: _ClassVar[int]
    scene: _planning_scene_pb2.PlanningScene
    def __init__(self, scene: _Optional[_Union[_planning_scene_pb2.PlanningScene, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from make87_messages_ros2.jazzy.geographic_msgs.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WayPoint(_message.Message):
    __slots__ = ["id", "position", "props"]
    ID_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    PROPS_FIELD_NUMBER: _ClassVar[int]
    id: _uuid_pb2.UUID
    position: _geo_point_pb2.GeoPoint
    props: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., position: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ..., props: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/srv/get_trajectory_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import trajectory_states_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_trajectory__states__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/jazzy/cartographer_ros_msgs/srv/get_trajectory_states.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.srv\x1aJmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/status_response.proto\x1aLmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/trajectory_states.proto\"\x1c\n\x1aGetTrajectoryStatesRequest\"\xd6\x01\n\x1bGetTrajectoryStatesResponse\x12T\n\x06status\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.StatusResponse\x12\x61\n\x11trajectory_states\x18\x02 \x01(\x0b\x32\x46.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.TrajectoryStatesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.srv.get_trajectory_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETTRAJECTORYSTATESREQUEST']._serialized_start=292
  _globals['_GETTRAJECTORYSTATESREQUEST']._serialized_end=320
  _globals['_GETTRAJECTORYSTATESRESPONSE']._serialized_start=323
  _globals['_GETTRAJECTORYSTATESRESPONSE']._serialized_end=537
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TsrVisionOnly(_message.Message):
    __slots__ = ["header", "ros2_header", "vision_only_sign_type_display1", "vision_only_supplementary_sign_type_display1", "vision_only_sign_type_display2", "vision_only_supplementary_sign_type_display2", "vision_only_sign_type_display3", "vision_only_supplementary_sign_type_display3", "vision_only_sign_type_display4", "vision_only_supplementary_sign_type_display4"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SIGN_TYPE_DISPLAY1_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SUPPLEMENTARY_SIGN_TYPE_DISPLAY1_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SIGN_TYPE_DISPLAY2_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SUPPLEMENTARY_SIGN_TYPE_DISPLAY2_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SIGN_TYPE_DISPLAY3_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SUPPLEMENTARY_SIGN_TYPE_DISPLAY3_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SIGN_TYPE_DISPLAY4_FIELD_NUMBER: _ClassVar[int]
    VISION_ONLY_SUPPLEMENTARY_SIGN_TYPE_DISPLAY4_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    vision_only_sign_type_display1: int
    vision_only_supplementary_sign_type_display1: int
    vision_only_sign_type_display2: int
    vision_only_supplementary_sign_type_display2: int
    vision_only_sign_type_display3: int
    vision_only_supplementary_sign_type_display3: int
    vision_only_sign_type_display4: int
    vision_only_supplementary_sign_type_display4: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., vision_only_sign_type_display1: _Optional[int] = ..., vision_only_supplementary_sign_type_display1: _Optional[int] = ..., vision_only_sign_type_display2: _Optional[int] = ..., vision_only_supplementary_sign_type_display2: _Optional[int] = ..., vision_only_sign_type_display3: _Optional[int] = ..., vision_only_supplementary_sign_type_display3: _Optional[int] = ..., vision_only_sign_type_display4: _Optional[int] = ..., vision_only_supplementary_sign_type_display4: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SpawnRequest(_message.Message):
    __slots__ = ["header", "x", "y", "theta", "name"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    THETA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    x: float
    y: float
    theta: float
    name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., theta: _Optional[float] = ..., name: _Optional[str] = ...) -> None: ...

class SpawnResponse(_message.Message):
    __slots__ = ["header", "name"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav_msgs/srv/load_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_humble_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/humble/nav_msgs/srv/load_map.proto\x12(make87_messages_ros2.humble.nav_msgs.srv\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/nav_msgs/msg/occupancy_grid.proto\"O\n\x0eLoadMapRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07map_url\x18\x02 \x01(\t\"\x95\x01\n\x0fLoadMapResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x44\n\x03map\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.nav_msgs.msg.OccupancyGrid\x12\x0e\n\x06result\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav_msgs.srv.load_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOADMAPREQUEST']._serialized_start=199
  _globals['_LOADMAPREQUEST']._serialized_end=278
  _globals['_LOADMAPRESPONSE']._serialized_start=281
  _globals['_LOADMAPRESPONSE']._serialized_end=430
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.clearpath_platform_msgs.msg import drive_feedback_pb2 as _drive_feedback_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Feedback(_message.Message):
    __slots__ = ["header", "ros2_header", "drivers", "commanded_mode", "actual_mode"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    DRIVERS_FIELD_NUMBER: _ClassVar[int]
    COMMANDED_MODE_FIELD_NUMBER: _ClassVar[int]
    ACTUAL_MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    drivers: _containers.RepeatedCompositeFieldContainer[_drive_feedback_pb2.DriveFeedback]
    commanded_mode: int
    actual_mode: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., drivers: _Optional[_Iterable[_Union[_drive_feedback_pb2.DriveFeedback, _Mapping]]] = ..., commanded_mode: _Optional[int] = ..., actual_mode: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ForceResistance(_message.Message):
    __slots__ = ["name", "px", "py", "pz", "fx", "fy", "fz"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PX_FIELD_NUMBER: _ClassVar[int]
    PY_FIELD_NUMBER: _ClassVar[int]
    PZ_FIELD_NUMBER: _ClassVar[int]
    FX_FIELD_NUMBER: _ClassVar[int]
    FY_FIELD_NUMBER: _ClassVar[int]
    FZ_FIELD_NUMBER: _ClassVar[int]
    name: str
    px: float
    py: float
    pz: float
    fx: float
    fy: float
    fz: float
    def __init__(self, name: _Optional[str] = ..., px: _Optional[float] = ..., py: _Optional[float] = ..., pz: _Optional[float] = ..., fx: _Optional[float] = ..., fy: _Optional[float] = ..., fz: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/geographic_msgs/srv/update_geographic_map.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_changes_pb2 as make87__messages__ros2_dot_jazzy_dot_geographic__msgs_dot_msg_dot_geographic__map__changes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/geographic_msgs/srv/update_geographic_map.proto\x12.make87_messages_ros2.jazzy.geographic_msgs.srv\x1aKmake87_messages_ros2/jazzy/geographic_msgs/msg/geographic_map_changes.proto\"s\n\x1aUpdateGeographicMapRequest\x12U\n\x07updates\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.geographic_msgs.msg.GeographicMapChanges\">\n\x1bUpdateGeographicMapResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.geographic_msgs.srv.update_geographic_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UPDATEGEOGRAPHICMAPREQUEST']._serialized_start=203
  _globals['_UPDATEGEOGRAPHICMAPREQUEST']._serialized_end=318
  _globals['_UPDATEGEOGRAPHICMAPRESPONSE']._serialized_start=320
  _globals['_UPDATEGEOGRAPHICMAPRESPONSE']._serialized_end=382
# @@protoc_insertion_point(module_scope)
